@@ -19,6 +19,7 @@ import osaft.solutions.yosioka1955 as yosioka1955
 import osaft.solutions.doinikov1994rigid as doinikov1994rigid
 import osaft.solutions.doinikov1994compressible as doinikov1994compressible
 import osaft.solutions.settnes2012 as settnes2012
+import osaft.solutions.hasegawa1969 as hasegawa1969
 
 # Legacy names of modules
 Gorkov1962 = gorkov1962
@@ -27,3 +28,4 @@ Yosioka1955 = yosioka1955
 Doinikov1994Rigid = doinikov1994rigid
 Doinikov1994Compressible = doinikov1994compressible
 Settnes2012 = settnes2012
+Hasegawa1969 = hasegawa1969
