@@ -61,7 +61,7 @@ class InviscidFluid(BaseFrequencyComposite):
     # -------------------------------------------------------------------------
     @property
     def c_f(self) -> float:
-        r"""Wave speed in the fluid :math:`c_f` [m\s].
+        r"""Speed of sound in the fluid :math:`c_f` [m\s].
 
         :getter: returns the value for the frequency
         :setter: automatically invokes
