@@ -1,3 +1,5 @@
+from typing import Optional
+
 import matplotlib.pyplot as plt
 import numpy as np
 
@@ -12,7 +14,7 @@ class ARFPlotter(BasePlot):
         self._attr_name = None
 
     def plot_solution(
-            self, x_values: np.ndarray, data: ARFData, file_name: str,
+            self, x_values: np.ndarray, data: ARFData,
             ax: plt.Axes, plot_method, **kwargs,
     ) -> (plt.Figure, plt.Axes):
         fig, ax = self._create_figure(ax)
@@ -35,18 +37,14 @@ class ARFPlotter(BasePlot):
     def set_labels(
         ax: plt.Axes,
         attr_name: str,
-        norm_name: str = None,
+        norm_name: Optional[str] = None,
     ) -> None:
         ax.set_xlabel(f'Attribute {attr_name}')
 
         if norm_name is None:
             ax.set_ylabel(r'$F^{\mathrm{rad}}$ $\mathrm{[N]}$')
-            ax.set_title('ARF for different solutions')
         else:
             ax.set_ylabel('normalized ARF [-]')
-            ax.set_title(
-                f'Normalized ARF by {norm_name} for different solutions',
-            )
 
 
 if __name__ == '__main__':
