@@ -11,10 +11,14 @@ class BaseScatteringDoinikov1994(BaseScattering, ABC):
 
     :param N_max: Highest order mode included in the computation [-]
     """
+
     def __init__(self, N_max: int) -> None:
         """"init method"""
         super().__init__(N_max)
 
+    def potential_coefficient(self, n: int) -> complex:
+        return self.alpha_n(n) * self.field.A_in(n)
+
     # -------------------------------------------------------------------------
     # Velocity amplitudes
     # -------------------------------------------------------------------------
