@@ -26,7 +26,7 @@ class BaseDoinikov1994Compressible(BaseDoinikov1994, BaseSolution):
     :param zeta_f: bulk viscosity [Pa s]
     :param p_0: Pressure amplitude of the field [Pa]
     :param position: Position within the standing wave field [m]
-    :param wave_type: Type of wave, travel(l)ing or standing
+    :param wave_type: Type of wave, traveling or standing
     """
 
     # Supported wave_type for the class
