@@ -24,7 +24,7 @@ class BaseDoinikov1994Rigid(BaseDoinikov1994, BaseSolution):
     :param eta_f: shear viscosity [Pa s]
     :param zeta_f: bulk viscosity [Pa s]
     :param p_0: Pressure amplitude of the field [Pa]
-    :param wave_type: Type of wave, travel(l)ing or standing
+    :param wave_type: Type of wave, traveling or standing
     :param position: Position in the standing wave field [rad]
     """
 
