@@ -5,7 +5,7 @@ from typing import Optional, Union
 from osaft import log
 from osaft.core.backgroundfields import WaveType
 from osaft.core.frequency import Frequency
-from osaft.core.functions import SpecialFunctions as Sp
+from osaft.core.functions import BesselFunctions as Bf
 from osaft.core.functions import exp
 from osaft.core.geometries import Sphere
 from osaft.core.helper import StringFormatter as SF
@@ -31,7 +31,7 @@ class ScatteringField(
     :param eta_f: shear viscosity [Pa s]
     :param zeta_f: bulk viscosity [Pa s]
     :param p_0: Pressure amplitude of the field [Pa]
-    :param wave_type: Type of wave, travel(l)ing or standing
+    :param wave_type: Type of wave, traveling or standing
     :param position: Position in the standing wave field [rad]
     :param N_max: Highest order mode included in the computation [-]
     """
@@ -186,8 +186,8 @@ class ScatteringField(
     def _compute_xi_n(self, n: int) -> complex:
         # computation according to (3.13) and (3.20)
         new_value = -n * (n + 1)
-        new_value *= Sp.hankelh1(n, self.x) * Sp.hankelh1(n, self.x_v)
-        new_value += self.x * Sp.d1_hankelh1(n, self.x) * self.gamma_n(n)
+        new_value *= Bf.hankelh1(n, self.x) * Bf.hankelh1(n, self.x_v)
+        new_value += self.x * Bf.d1_hankelh1(n, self.x) * self.gamma_n(n)
 
         return new_value
 
@@ -200,8 +200,8 @@ class ScatteringField(
 
     def _compute_gamma_n(self, n: int) -> complex:
         # computation according to (3.13) and (3.20)
-        new_value = Sp.hankelh1(n, self.x_v)
-        new_value += self.x_v * Sp.d1_hankelh1(n, self.x_v)
+        new_value = Bf.hankelh1(n, self.x_v)
+        new_value += self.x_v * Bf.d1_hankelh1(n, self.x_v)
         return new_value
 
     def alpha_n(self, n: int) -> complex:
@@ -214,19 +214,19 @@ class ScatteringField(
     def _compute_alpha_n(self, n: int) -> complex:
         # computation according to (3.13), (3.14) and (3.20)
         if n == 0:
-            new_value = -Sp.besselj(1, self.x) / Sp.hankelh1(1, self.x)
+            new_value = -Bf.besselj(1, self.x) / Bf.hankelh1(1, self.x)
         elif n == 1:
             new_value = -2 * (1 - self.rho_t**2)
-            new_value *= Sp.besselj(1, self.x) * Sp.hankelh1(1, self.x_v)
+            new_value *= Bf.besselj(1, self.x) * Bf.hankelh1(1, self.x_v)
             new_value -= self.mu_1 * self.mu_3
             new_value /= self.mu_4
         else:
-            new_value = n * (n + 1) * Sp.besselj(n, self.x)
-            new_value *= Sp.hankelh1(n, self.x_v)
+            new_value = n * (n + 1) * Bf.besselj(n, self.x)
+            new_value *= Bf.hankelh1(n, self.x_v)
 
             new_value -= self.x * (
                 self.gamma_n(n) *
-                Sp.d1_besselj(n, self.x)
+                Bf.d1_besselj(n, self.x)
             )
             new_value /= self.xi_n(n)
         return new_value
@@ -244,14 +244,14 @@ class ScatteringField(
         if n == 0:
             new_value = 0.0
         elif n == 1:
-            new_value = self.mu_1 * Sp.hankelh1(1, self.x)
-            new_value -= self.mu_2 * Sp.besselj(1, self.x)
+            new_value = self.mu_1 * Bf.hankelh1(1, self.x)
+            new_value -= self.mu_2 * Bf.besselj(1, self.x)
 
             new_value *= -(1 - self.rho_t)
             new_value /= self.mu_4
         else:
-            new_value = Sp.d1_besselj(n, self.x) * Sp.hankelh1(n, self.x)
-            new_value -= Sp.besselj(n, self.x) * Sp.d1_hankelh1(n, self.x)
+            new_value = Bf.d1_besselj(n, self.x) * Bf.hankelh1(n, self.x)
+            new_value -= Bf.besselj(n, self.x) * Bf.d1_hankelh1(n, self.x)
             new_value *= self.x
             new_value /= -self.xi_n(n)
 
@@ -264,8 +264,8 @@ class ScatteringField(
         return self._mu_1.value
 
     def _compute_mu_1(self) -> complex:
-        out = self.rho_t * Sp.besselj(1, self.x)
-        out -= self.x * Sp.d1_besselj(1, self.x)
+        out = self.rho_t * Bf.besselj(1, self.x)
+        out -= self.x * Bf.d1_besselj(1, self.x)
         return out
 
     @property
@@ -275,8 +275,8 @@ class ScatteringField(
         return self._mu_2.value
 
     def _compute_mu_2(self) -> complex:
-        out = self.rho_t * Sp.hankelh1(1, self.x)
-        out -= self.x * Sp.d1_hankelh1(1, self.x)
+        out = self.rho_t * Bf.hankelh1(1, self.x)
+        out -= self.x * Bf.d1_hankelh1(1, self.x)
         return out
 
     @property
@@ -286,8 +286,8 @@ class ScatteringField(
         return self._mu_3.value
 
     def _compute_mu_3(self) -> complex:
-        out = (1 + 2 * self.rho_t) * Sp.hankelh1(1, self.x_v)
-        out += self.x_v * Sp.d1_hankelh1(1, self.x_v)
+        out = (1 + 2 * self.rho_t) * Bf.hankelh1(1, self.x_v)
+        out += self.x_v * Bf.d1_hankelh1(1, self.x_v)
         return out
 
     @property
@@ -298,8 +298,8 @@ class ScatteringField(
 
     def _compute_mu_4(self) -> complex:
         out = 2 * (1 - self.rho_t**2)
-        out *= Sp.hankelh1(1, self.x)
-        out *= Sp.hankelh1(1, self.x_v)
+        out *= Bf.hankelh1(1, self.x)
+        out *= Bf.hankelh1(1, self.x_v)
         out += self.mu_2 * self.mu_3
         return out
 
@@ -317,8 +317,8 @@ class ScatteringField(
         :param t: time [s]
         """
 
-        out = Sp.besselj(1, self.x) + self.alpha_n(1) * Sp.hankelh1(1, self.x)
-        out += 2 * self.beta_n(1) * Sp.hankelh1(1, self.x_v)
+        out = Bf.besselj(1, self.x) + self.alpha_n(1) * Bf.hankelh1(1, self.x)
+        out += 2 * self.beta_n(1) * Bf.hankelh1(1, self.x_v)
         out *= self.rho_t * self.A_in(1) * self.k_f
         out /= self.x
         out *= exp(-1j * self.omega * t)
