@@ -24,7 +24,13 @@ class ARF(BaseARF, BaseSphereFrequencyComposite, BaseSolution):
 
     .. note::
        This model is based on the following assumptions:
-       - :math:`\\lambda \\gg R`
+       - :math:`\\lambda \\gg R_0`
+
+    .. note::
+        The expression for the travelling wave has been corrected. The
+        expression in the article by Settnes & Bruus was off by a factor of 2.
+        The error was reported in an article
+        `Marston (2013) <https://asa.scitation.org/doi/pdf/10.1121/1.4799400>`_
 
     :param f: Frequency [Hz]
     :param R_0: Radius of the sphere [m]
@@ -138,8 +144,8 @@ class ARF(BaseARF, BaseSphereFrequencyComposite, BaseSolution):
         return out
 
     def _traveling_wave_solution(self) -> float:
-        out = pi * self.R_0**3 * self.k_f.real * self.f_2.imag * self.E_ac
-        return out
+        # This expression has been corrected according to Marston (2013).
+        return 2 * pi * self.R_0**3 * self.k_f.real * self.f_2.imag * self.E_ac
 
     def __repr__(self):
         return (
