@@ -5,7 +5,7 @@ from typing import Optional, Union
 from osaft import log
 from osaft.core.backgroundfields import WaveType, WrongWaveTypeError
 from osaft.core.frequency import Frequency
-from osaft.core.functions import SpecialFunctions as SP
+from osaft.core.functions import BesselFunctions as Bf
 from osaft.core.functions import conj, pi, sin
 from osaft.core.geometries import Sphere
 from osaft.core.helper import StringFormatter as SF
@@ -82,7 +82,7 @@ class ARF(ScatteringField, BaseARF):
 
         self._F.is_computed_by(
             self._sigma,
-            self._labmda_rho,
+            self._lambda_rho,
             self.field._wave_type,
             self.scatterer._k_f,
             self.sphere._R_0,
@@ -480,7 +480,7 @@ class ARF(ScatteringField, BaseARF):
         """
         out = (-1) ** n / (2 * n + 1)
         out *= self.k_s * self.B_n(n)
-        out *= SP.d1_besselj(n, self.k_s * self.R_0)
+        out *= Bf.d1_besselj(n, self.k_s * self.R_0)
         return out
 
     def _compute_M_n(self, n: int) -> complex:
@@ -489,7 +489,7 @@ class ARF(ScatteringField, BaseARF):
         """
         out = (-1) ** n / (2 * n + 1)
         out *= self.B_n(n)
-        out *= SP.besselj(n, self.k_s * self.R_0)
+        out *= Bf.besselj(n, self.k_s * self.R_0)
         return out
 
 
