@@ -279,6 +279,12 @@ class ChangingInt(ChangingNumber):
 
 class NumericTestCase(unittest.TestCase):
 
+    def setUp(self) -> None:
+        # Create seed
+        seed = np.random.randint(1, 10000)
+        self.seed = seed
+        self.rng = np.random.default_rng(seed)
+
     def assertAlmostEqual(
         self,
         val1: Number,
@@ -311,7 +317,7 @@ class NumericTestCase(unittest.TestCase):
             print(msg)
 
         self._assertAlmostEqual(val1.real, val2.real, threshold)
-        if isinstance(val1, complex) and isinstance(val2, complex):
+        if isinstance(val1, complex) or isinstance(val2, complex):
             self._assertAlmostEqual(val1.imag, val2.imag, threshold, user_msg)
 
     def _assertAlmostEqual(
@@ -344,50 +350,54 @@ class NumericTestCase(unittest.TestCase):
 
             self.assertTrue(expr=test, msg=msg)
 
+    def random_z(self, low: float = -10, high: float = 10) -> complex:
+        a = self.rng.uniform(low, high)
+        b = self.rng.uniform(low, high)
+        return a + b * 1j
+
 
 class BaseTest(NumericTestCase):
 
     def setUp(self) -> None:
 
         # Create
-        seed = np.random.randint(1, 10000)
-        self._seed = seed
+        super().setUp()
 
         # set of all passive attributes that have a value of type float
         # that appear in classes in this module
 
         # Geometry
-        self._R_0 = ChangingFloat('R_0', 1e-6, seed, low=0)
+        self._R_0 = ChangingFloat('R_0', 1e-6, self.seed, low=0)
         # Frequency
-        self._f = ChangingFloat('f', 1e6, seed, low=0)
+        self._f = ChangingFloat('f', 1e6, self.seed, low=0)
         # Inviscid Fluid
-        self._c_f = ChangingFloat('c_f', 1.5e3, seed, low=0)
-        self._rho_f = ChangingFloat('rho_f', 1e3, seed, low=0)
+        self._c_f = ChangingFloat('c_f', 1.5e3, self.seed, low=0)
+        self._rho_f = ChangingFloat('rho_f', 1e3, self.seed, low=0)
         # Compressible Particle (Inviscid Fluid)
-        self._c_s = ChangingFloat('c_s', 2.5e3, seed, low=0)
+        self._c_s = ChangingFloat('c_s', 2.5e3, self.seed, low=0)
         # Compressible Particle (Viscous Fluid)
-        self._eta_s = ChangingFloat('eta_s', 1e-3, seed, low=0)
-        self._zeta_s = ChangingFloat('zeta_s', 1e-3, seed, low=0)
+        self._eta_s = ChangingFloat('eta_s', 1e-3, self.seed, low=0)
+        self._zeta_s = ChangingFloat('zeta_s', 1e-3, self.seed, low=0)
         # Viscous Fluid
-        self._eta_f = ChangingFloat('eta_f', 1e-2, seed, low=0)
-        self._zeta_f = ChangingFloat('zeta_f', 1e-2, seed, low=0)
+        self._eta_f = ChangingFloat('eta_f', 1e-2, self.seed, low=1e-6)
+        self._zeta_f = ChangingFloat('zeta_f', 1e-2, self.seed, low=0)
         # Viscoelastic Fluid
-        self._eta_p = ChangingFloat('eta_p', 1e-3, seed, low=0)
-        self._zeta_p = ChangingFloat('zeta_p', 1e-3, seed, low=0)
-        self._lambda_M = ChangingFloat('lambda_M', 1e-3, seed, low=0)
+        self._eta_p = ChangingFloat('eta_p', 1e-3, self.seed, low=0)
+        self._zeta_p = ChangingFloat('zeta_p', 1e-3, self.seed, low=0)
+        self._lambda_M = ChangingFloat('lambda_M', 1e-3, self.seed, low=0)
         # Rigid Solid
-        self._rho_s = ChangingFloat('rho_s', 1.5e3, seed, low=0)
+        self._rho_s = ChangingFloat('rho_s', 1.5e3, self.seed, low=0)
         # Elastic solid
-        self._E_s = ChangingFloat('E_s', 75e6, seed, low=0)
-        self._nu_s = ChangingFloat('nu_s', 0.3, seed, low=0, high=0.49)
+        self._E_s = ChangingFloat('E_s', 75e6, self.seed, low=0)
+        self._nu_s = ChangingFloat('nu_s', 0.3, self.seed, low=0, high=0.49)
         # Background Field
-        self._p_0 = ChangingFloat('p_0', 1e5, seed, low=0)
+        self._p_0 = ChangingFloat('p_0', 1e5, self.seed, low=0)
         self._position = ChangingFloat(
-            'position', np.pi / 4, seed, low=0, high=2 * np.pi,
+            'position', np.pi / 4, self.seed, low=0, high=2 * np.pi,
         )
         self._wave_type = ChangingFromList(
             'wave_type', WaveType.STANDING,
-            WaveType, seed,
+            WaveType, self.seed,
         )
 
         self.test_variables = {
@@ -493,6 +503,7 @@ class BaseTest(NumericTestCase):
             dict_of_methods: dict[str, dict[tuple[Any]]],
             n_end: int = 5,
             threshold: float = 1e-12,
+            zero: Optional[float] = None,
     ) -> None:
         """Tests the methods inside `dict_of_methods` of self & self.cls
 
@@ -507,12 +518,13 @@ class BaseTest(NumericTestCase):
             tested
         :param n_end: n in [0, 1, ..., n_end]; tested in reversed order
         :param threshold: comparing threshold for the whole dict
+        :param threshold: value below which test values are assumed to be zero
         """
 
         for method, args in dict_of_methods.items():
             func_1 = getattr(self, method)
             func_2 = getattr(self.cls, method)
-            for n in reversed(np.arange(n_end + 1)):
+            for n in reversed(np.arange(n_end)):
 
                 if args is not None:
                     if isinstance(args, tuple):
@@ -819,7 +831,7 @@ class BaseTest(NumericTestCase):
 
         super().assertAlmostEqual(
             val1, val2, threshold, print_results,
-            user_msg=f'\nseed number {self._seed}\n',
+            user_msg=f'\nseed number {self.seed}\n',
         )
 
 
