@@ -6,9 +6,9 @@ from random import randint, random
 import numpy as np
 
 from osaft import ViscoelasticFluid, ViscousFluid, WaveType
+from osaft.core.functions import BesselFunctions as Bf
 from osaft.core.functions import LegendreFunctions as Leg
-from osaft.core.functions import SpecialFunctions as Sp
-from osaft.core.functions import exp, pi
+from osaft.core.functions import exp, full_range, pi
 
 
 class BaseHelperScattering:
@@ -59,12 +59,12 @@ class HelperScattering(BaseHelperScattering):
     def V_r_i(self, n, r) -> complex:
         out = self.cls.A_in(n)
         out *= self.cls.k_f
-        out *= Sp.d1_besselj(n, self.cls.k_f * r)
+        out *= Bf.d1_besselj(n, self.cls.k_f * r)
         return out
 
     def V_theta_i(self, n, r) -> complex:
         out = self.cls.A_in(n)
-        out *= Sp.besselj(n, self.cls.k_f * r)
+        out *= Bf.besselj(n, self.cls.k_f * r)
         out /= r
         return out
 
@@ -78,19 +78,20 @@ class HelperScattering(BaseHelperScattering):
         self,
         r, theta,
         t,
-        scattering,
+        scattered,
         incident,
         mode=None,
     ) -> float:
-        if scattering and incident:
-            v = lambda l, x: (
-                self.V_r_sc(l, x)
-                + self.V_r_i(l, x)
-            )
-        elif scattering and not incident:
-            v = lambda l, x: self.V_r_sc(l, x)
-        elif not scattering and incident:
-            v = lambda l, x: self.V_r_i(l, x)
+        if scattered and incident:
+            def v(l, x):
+                return self.V_r_sc(l, x) + self.V_r_i(l, x)
+        elif scattered and not incident:
+            v = self.V_r_sc
+        elif not scattered and incident:
+            v = self.V_r_i
+        else:
+            def v(l, x):
+                return 0
 
         out = exp(-1j * self.cls.omega * t)
         if mode is not None:
@@ -99,20 +100,26 @@ class HelperScattering(BaseHelperScattering):
             out *= Leg.cos_poly(
                 theta, [
                     v(n, r)
-                    for n in range(self.cls.N_max + 1)
+                    for n in full_range(self.cls.N_max)
                 ],
             )
         return out
 
     def tangential_acoustic_fluid_velocity(
-        self, r, theta, t, scattering, incident, mode=None,
+        self, r, theta, t, scattered, incident, mode=None,
     ) -> float:
-        if scattering and incident:
-            v = lambda l, x: self.V_theta_sc(l, x) + self.V_theta_i(l, x)
-        elif scattering and not incident:
-            v = lambda l, x: self.V_theta_sc(l, x)
-        elif not scattering and incident:
-            v = lambda l, x: self.V_theta_i(l, x)
+        if scattered and incident:
+            def v(l, x):
+                if l == 0:
+                    return 0
+                return self.V_theta_sc(l, x) + self.V_theta_i(l, x)
+        elif scattered and not incident:
+            v = self.V_theta_sc
+        elif not scattered and incident:
+            v = self.V_theta_i
+        else:
+            def v(l, x):
+                return 0
 
         out = exp(-1j * self.cls.omega * t)
         if mode is not None:
@@ -122,7 +129,7 @@ class HelperScattering(BaseHelperScattering):
                 theta,
                 [
                     v(n, r) for n in
-                    range(self.cls.N_max + 1)
+                    full_range(0, self.cls.N_max)
                 ],
             )
         return out
@@ -347,10 +354,9 @@ class HelperScattering(BaseHelperScattering):
 
     def test_boundary_conditions(self) -> None:
         test_tangential = False
-        fluid_type = type(self.cls.fluid)
         if (
-            isinstance(fluid_type, ViscousFluid)
-            or isinstance(fluid_type, ViscoelasticFluid)
+            isinstance(self.cls.fluid, ViscousFluid)
+            or isinstance(self.cls.fluid, ViscoelasticFluid)
         ):
             test_tangential = True
 
