@@ -94,14 +94,14 @@ class TestBaseSphereFrequencyComposite(BaseTest):
         cls = BaseSphereFrequencyComposite(f, R)
 
         self.assertAlmostEqual(R, cls.R_0)
-        self.assertAlmostEqual(V(R), cls.V)
-        self.assertAlmostEqual(A(R), cls.A)
+        self.assertAlmostEqual(V(R), cls.volume)
+        self.assertAlmostEqual(A(R), cls.area)
 
         R = 4.39e-6
         cls.R_0 = R
         self.assertAlmostEqual(R, cls.R_0)
-        self.assertAlmostEqual(V(R), cls.V)
-        self.assertAlmostEqual(A(R), cls.A)
+        self.assertAlmostEqual(V(R), cls.volume)
+        self.assertAlmostEqual(A(R), cls.area)
 
     def test_TypeError(self):
         self.assertRaises(
