@@ -75,13 +75,13 @@ class TestARF(BaseKing):
         out += self.FFGG(n)**2
         return out
 
-    def compute_general_ARF(self, n):
+    def compute_general_ARF(self):
         if self.wave_type == WaveType.TRAVELLING:
-            return self.compute_traveling_general_ARF(n)
+            return self.compute_traveling_general_ARF()
         elif self.wave_type == WaveType.STANDING:
-            return self.compute_standing_general_ARF(n)
+            return self.compute_standing_general_ARF()
 
-    def compute_standing_general_ARF(self, n):
+    def compute_standing_general_ARF(self):
         alpha = self.cls.alpha
         # n = 0
         out = self.FFGG(0)
@@ -94,7 +94,7 @@ class TestARF(BaseKing):
         tmp *= alpha**2 - 3 * (1 - 1 / self.cls.rho_tilde)
         out -= tmp
         # n > 1
-        for i in range(2, n):
+        for i in range(2, self.cls.N_max):
             tmp = (-1)**i
             tmp *= (i + 1) / alpha**(2 * i + 3)
             tmp *= self.FFGG(i)
@@ -104,12 +104,12 @@ class TestARF(BaseKing):
             out += tmp
 
         out *= pi * self.cls.rho_f
-        out *= np.abs(self.cls.field.A) ** 2
+        out *= np.abs(self.cls.field.A)**2
         out *= sin(2 * self.position)
 
         return out
 
-    def compute_traveling_general_ARF(self, n):
+    def compute_traveling_general_ARF(self):
         alpha = self.cls.alpha
         # n = 0
         out = 1 / self.HH(0)
@@ -119,14 +119,14 @@ class TestARF(BaseKing):
         tmp /= alpha**8
         out += tmp
         # n > 1
-        for i in range(2, n):
+        for i in range(2, self.cls.N_max):
             tmp = (i + 1) / self.HH(i)
             tmp *= (alpha**2 - i * (i + 2))**2
             tmp /= alpha**(4 * i + 4)
             out += tmp
 
         out *= 2 * pi * self.cls.rho_f
-        out *= np.abs(self.cls.field.A) ** 2 / alpha ** 2
+        out *= np.abs(self.cls.field.A)**2 / alpha**2
 
         return out
 
@@ -152,11 +152,9 @@ class TestARF(BaseKing):
 
     def test_general_solution(self) -> None:
         for n in range(0, self.n_runs + 3):
-            self.cls.N_max = n
             self.do_testing(
                 func_1=self.cls.compute_arf,
                 func_2=self.compute_general_ARF,
-                args_2=n,
                 threshold=5e-4,
             )
 
