@@ -8,8 +8,8 @@ class TestScattering(BaseTest):
         super().setUp()
 
         self.cls = yosioka1955.BaseYosioka(
-            frequency=self.f,
-            radius=self.R_0,
+            f=self.f,
+            R_0=self.R_0,
             rho_s=self.rho_s, c_s=self.c_s,
             rho_f=self.rho_f, c_f=self.c_f,
             p_0=self.p_0,
